@@ -188,6 +188,7 @@ ews_backend_new_child (EEwsBackend *backend,
 
 	display_name = e_ews_folder_get_name (folder);
 	e_source_set_display_name (source, display_name);
+	e_source_set_enabled (source, TRUE);
 
 	switch (e_ews_folder_get_folder_type (folder)) {
 		case E_EWS_FOLDER_TYPE_CALENDAR:
@@ -339,13 +340,8 @@ static void
 ews_backend_sync_deleted_folders (EEwsBackend *backend,
                                   GSList *list)
 {
-	ECollectionBackend *collection_backend;
-	ESourceRegistryServer *server;
 	GSList *link;
 
-	collection_backend = E_COLLECTION_BACKEND (backend);
-	server = e_collection_backend_ref_server (collection_backend);
-
 	for (link = list; link != NULL; link = g_slist_next (link)) {
 		const gchar *folder_id = link->data;
 		ESource *source = NULL;
@@ -359,12 +355,10 @@ ews_backend_sync_deleted_folders (EEwsBackend *backend,
 
 		/* This will trigger a "child-removed" signal and
 		 * our handler will remove the hash table entry. */
-		e_source_registry_server_remove_source (server, source);
+		e_source_remove_sync (source, NULL, NULL);
 
 		g_object_unref (source);
 	}
-
-	g_object_unref (server);
 }
 
 static void
@@ -513,6 +507,7 @@ add_remote_sources (EEwsBackend *backend)
 				E_SERVER_SIDE_SOURCE (source), TRUE);
 			e_server_side_source_set_remote_deletable (
 				E_SERVER_SIDE_SOURCE (source), TRUE);
+			e_source_set_enabled (source, TRUE);
 			e_source_registry_server_add_source (registry, source);
 		} else {
 			GError *error = NULL;
@@ -1029,7 +1024,6 @@ ews_backend_authenticate_sync (EBackend *backend,
 	EEwsConnection *connection;
 	CamelEwsSettings *ews_settings;
 	ESourceAuthenticationResult result = E_SOURCE_AUTHENTICATION_ERROR;
-	gchar *hosturl;
 
 	g_return_val_if_fail (E_IS_EWS_BACKEND (backend), E_SOURCE_AUTHENTICATION_ERROR);
 
